local LDB
local parent = CreateFrame('Frame')

 -- Get a reference to the lib
local LibQTip = LibStub('LibQTip-1.0')
local tooltip = nil
local tooltip2 = nil

local RARITY_COLOR_HEX = {	
	[1] = "ff9d9d9d", --poor
	[2] = "ffffffff", --common
	[3] = "ff1eff00", --uncommon
	[4] = "ff0070dd", --rare
	[5] = "ffa335ee", --epic
	[6] = "ffff8000", --legendary
}

local function GetRarityColor(pet)
if pet then
	local health, maxHealth, power, speed, rarity = C_PetJournal.GetPetStats(pet)
	local rarityColor = RARITY_COLOR_HEX[rarity]
	if not rarity then 
		rarityColor = "ffffffff"
	end
	return rarityColor
end
end

local function UpdateDisplay()	
	if lastpetId ~= nil then
		LDB.text = lastpetText
		LDB.icon = lastpetIcon
	end
	
	local summonedPetID = C_PetJournal.GetSummonedPetGUID();
		
	if summonedPetID then
		local speciesID, customName, petlevel, xp, maxXp, displayID, isFavorite, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(summonedPetID)
		local creatureName = petName
			if customName then
				creatureName = customName
			end
			if creatureName then
			LDB.text = format("|cff00ff00%s|r", creatureName)
			LDB.icon = petIcon
			lastpetText = creatureName
			lastpetId = summonedPetID
			lastpetIcon = petIcon
			return
			end
	end
	
end

local function ModifiedClick(button, Id)
local speciesID, customName, petlevel, xp, maxXp, displayID, isFavorite, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(Id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end
	
	if IsShiftKeyDown() then
		C_PetJournal.PickupPet(Id);
	elseif IsAltKeyDown() and not IsControlKeyDown() then
		fav1id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 1.", creatureName))
	elseif IsControlKeyDown() and not IsAltKeyDown() then
		fav2id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 2.", creatureName))
	elseif IsControlKeyDown() and IsAltKeyDown() then
		fav3id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 3.", creatureName))
	else
		C_PetJournal.SummonPetByGUID(Id);
	end
	LibQTip:Release(tooltip)
	tooltip = nil
end

local function OnEnter(self)
tooltip2 = LibQTip:Acquire("BrokerPetsTooltip2", 1, "LEFT") 
self.tooltip2 = tooltip2
  
   -- Use smart anchoring code to anchor the tooltip to our frame
tooltip2:SmartAnchorTo(self)
tooltip2:Clear()
	local numPets, numOwned = C_PetJournal.GetNumPets(false);
	tooltip2:AddHeader('|cff00ffffBrokerPets|r')
	tooltip2:AddLine("|cffffff00<Right Click>|r to open pet list")
	tooltip2:AddLine("|cffffff00<Left Click>|r to summon/dismiss pet")
	tooltip2:AddLine("|cffffff00<ALT-Right Click>|r to summon a random pet")
	tooltip2:AddLine("|cffffff00<CTRL-Right Click>|r to summon a random favorite pet")
	tooltip2:AddLine("|cffffff00<Shift-Left Click>|r plugin to open pet journal")
	tooltip2:AddLine("|cffffff00<Shift-Left Click>|r pet to pick it up")
	if togglefavoritepets then
	tooltip2:AddLine("|cffffff00<Shift-Right Click>|r to toggle favorite pet list (|cff00ff00On|r)")
	else
	tooltip2:AddLine("|cffffff00<Shift-Right Click>|r to toggle favorite pet list (|cffff0000Off|r)")
	end
	--tooltip2:AddLine("|cffffff00<CTRL-ALT-Right Click>|r plugin to open filter menu")
	if fav1id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, isFavorite, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav1id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("|cffffff00<ALT-Click>|r |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("|cffffff00<ALT-Click>|r pet to set as favorite 1")
	end
	if fav2id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, isFavorite, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav2id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("|cffffff00<CTRL-Click>|r |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("|cffffff00<CTRL-Click>|r pet to set as favorite 2")
	end
	if fav3id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, isFavorite, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav3id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("|cffffff00<CTRL-ALT-Click>|r |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("|cffffff00<CTRL-ALT-Click>|r pet to set as favorite 3")
	end
	if numOwned == 0 then
		tooltip2:AddLine("|cffff0000You have no pets|r")
	else
		tooltip2:AddLine(string.format("|cff00ff00You have %s pets|r", numOwned))
	end
	 -- Show it
	if tooltip and tooltip:IsShown() then
		LibQTip:Release(self.tooltip2)
		self.tooltip2 = nil
	else
		tooltip2:Show()
	end
end

local function CreatePetTooltip(self)
   -- Acquire a tooltip with 1 columns, aligned to left
tooltip = LibQTip:Acquire("BrokerPetsTooltip", 1, "LEFT") 
self.tooltip = tooltip 
if tooltip:IsShown() then
	LibQTip:Release(self.tooltip)
	self.tooltip = nil	
else
tooltip:EnableMouse(true)
tooltip:SetAutoHideDelay(1, self)
  
   -- Use smart anchoring code to anchor the tooltip to our frame
tooltip:SmartAnchorTo(self)
tooltip:Clear()
	local numPets, numOwned = C_PetJournal.GetNumPets(false)
	local summonedPetID = C_PetJournal.GetSummonedPetGUID();
	for i = 1, numOwned do
		local petID, speciesID, isOwned, customName, petlevel, favorite, isRevoked, name, icon, petType, companionID, tooltipinfo, description, isWild, canBattle, isTradeable, isUnique, obtainable = C_PetJournal.GetPetInfoByIndex(i)
			local creatureName = name
			if customName then
				creatureName = format("%s |cff00ffff(%s)|r", name, customName)
			end
		local PetFlag = GetRarityColor(petID)
		local fav = ""
		if favorite then
			fav = "*"
		end
		if isOwned and not togglefavoritepets then
		local isSummonable = C_PetJournal.PetIsSummonable(petID)
		 -- Add a new line, using all columns
			if isSummonable then
				if summonedPetID == petID then
					tooltip:AddLine(format("|T%s:16|t %s|cff00ff00%s|r |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				else
					tooltip:AddLine(format("|T%s:16|t %s%s |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				end
			else
				tooltip:AddLine(format("|T%s:16|t %s|cff848484%s|r |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
				tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
			end
		elseif isOwned and favorite and togglefavoritepets then
		local isSummonable = C_PetJournal.PetIsSummonable(petID)
			-- Add a new line, using all columns
			if isSummonable then
				if summonedPetID == petID then
					tooltip:AddLine(format("|T%s:16|t %s|cff00ff00%s|r |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				else
					tooltip:AddLine(format("|T%s:16|t %s%s |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				end
			else
				tooltip:AddLine(format("|T%s:16|t %s|cff848484%s|r |c%s(%s)|r", icon, fav, creatureName, PetFlag, petlevel))
				tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
			end
		end				
	end
tooltip:UpdateScrolling(500)
-- Show it
	tooltip:Show()
	LibQTip:Release(self.tooltip2)
	tooltip2 = nil
end
end
 
local function OnLeave(self)   
   -- Release the tooltip
   LibQTip:Release(self.tooltip2)
   self.tooltip2 = nil  
end


local function OnClick(self, button)
if not InCombatLockdown() then
	if (button == 'RightButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown())  then
		CreatePetTooltip(self)
	end
	if (IsShiftKeyDown() and button == 'LeftButton') then	
		ToggleCollectionsJournal(2)	
	end
	if (IsAltKeyDown() and not IsControlKeyDown() and button == 'RightButton') and not InCombatLockdown() then
		C_PetJournal.SummonRandomPet(true)
	end
	if (IsControlKeyDown() and not IsAltKeyDown() and button == 'RightButton') and not InCombatLockdown() then
		C_PetJournal.SummonRandomPet(false)
	end
	if (button == 'LeftButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown()) then	
		if lastpetId ~= nil then
			C_PetJournal.SummonPetByGUID(lastpetId);
		end
	end	
	if (IsShiftKeyDown() and button == 'RightButton') then
		if togglefavoritepets == true then
			togglefavoritepets = false
		else
			togglefavoritepets = true
		end
	end
	if (button == 'LeftButton' and IsAltKeyDown() and not IsControlKeyDown()) then
		if fav1id ~= nil then
			C_PetJournal.SummonPetByGUID(fav1id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and not IsAltKeyDown()) then
		if fav2id ~= nil then
			C_PetJournal.SummonPetByGUID(fav2id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and IsAltKeyDown()) then
		if fav3id ~= nil then
			C_PetJournal.SummonPetByGUID(fav3id)
		end
	end
	--[[if (button == 'RightButton'and not IsShiftKeyDown() and IsAltKeyDown() and IsControlKeyDown()) then
		if IsAddOnLoaded("Blizzard_PetJournal") then
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		else
			local loaded, reason = LoadAddOn("Blizzard_PetJournal")
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		end
	end]]
end
end

function parent:PLAYER_LOGIN()
	LDB = LibStub('LibDataBroker-1.1'):NewDataObject('BrokerPets', {
		icon = "Interface\\Icons\\INV_Misc_QuestionMark.blp",
		text = "BrokerPets",
		type = 'data source',
		--OnTooltipShow = OnTooltipShow,
		OnEnter = OnEnter,
		OnLeave = OnLeave,
		OnClick = OnClick,
	})

	self:RegisterEvent('COMPANION_UPDATE')
	self.COMPANION_UPDATE = UpdateDisplay
	
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE")
	self.PET_JOURNAL_LIST_UPDATE = UpdateDisplay

	UpdateDisplay()
end

 -- Somewhere in the anchor initialization
parent:SetScript('OnEnter', OnEnter)
parent:SetScript('OnLeave', OnLeave)
parent:SetScript('OnEvent', function(self, event, ...) self[event](self, ...) end)
parent:RegisterEvent('PLAYER_LOGIN')